@@ -2,6 +2,7 @@ import base64
 import hmac
 import json
 import os
+import socket
 import threading
 import time
 import uuid
@@ -34,21 +35,6 @@ class MqttSendMessageException(WinhyeException):
 
 class MqttClint:
     _instance = None
-    lock = threading.Lock()
-
-    def __new__(cls, *args, **kwargs):
-        """
-        设置为单例以保证线程中client一致安全
-        :param args:
-        :param kwargs:
-        """
-        if cls._instance:
-
-            return cls._instance
-        else:
-            with cls.lock:
-                cls._instance = super().__new__(cls)
-                return cls._instance
 
     def __init__(self, mqtt_config: dict, thread=False):
         """
@@ -67,12 +53,13 @@ class MqttClint:
         secret_key = mqtt_config["AccessKey_Secret"]
         instance_id = mqtt_config["instance_id"]
         group_id = mqtt_config["group_id"]
-        # client_id不能重复，使用自定义字符串 app_id-env-idc-pid(进程id)
+        # client_id不能重复，使用自定义字符串 app_id-idc-hostname-pid(进程id)
         app_id = os.environ.get("APP_ID", str(uuid.uuid1())[:10])
-        env = os.environ.get("ENV", str(uuid.uuid1())[:10])
         idc = os.environ.get("IDC", str(uuid.uuid1())[:10])
+        hostname = socket.gethostname()
+        hostname_last = hostname[hostname.rfind("-") + 1:]  # 使用hostname最后几位
         pid = os.getpid()
-        self.client_id = f"{group_id}@@@{app_id}-{env}-{idc}-{pid}"
+        self.client_id = f"{group_id}@@@{app_id}-{idc}-{hostname_last}-{pid}"
         if thread:
             self.client_id += f"-{threading.currentThread().ident}"
         username = 'Signature' + '|' + access_key + '|' + instance_id
